//******************************************************************************************
// Motoko, a 2D GUI for games.
// Copyright (C) 2006  Gorka Surez Garca
// 
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
// 
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
// 
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//******************************************************************************************
#ifndef _MOTOKO_CHECKBUTTON_H_
#define _MOTOKO_CHECKBUTTON_H_
//******************************************************************************************
// Includes
//******************************************************************************************
#include "Base.h"
#include "Appearance.h"
#include "Control.h"
#include "ITextControl.h"
//******************************************************************************************
// Constants
//******************************************************************************************
#define MAX_CHECKBUTTON_RECTS 2
//******************************************************************************************
// Namespace Motoko
//******************************************************************************************
namespace Motoko
{
	//--------------------------------------------------------------------------------------
	/// Class that represents a generic label box.
	//--------------------------------------------------------------------------------------
	class DLLAPI CheckButton : public Control, public ITextControl
	{
		//----------------------------------------------------------------------------------
		// Private members
		//----------------------------------------------------------------------------------
		private:
			
		//----------------------------------------------------------------------------------
		// Protected members
		//----------------------------------------------------------------------------------
		protected:
			//------------------------------------------------------------------------------
			// Properties
			//------------------------------------------------------------------------------
			SDL_Surface * PictureChecked;
			bool Value;

			//------------------------------------------------------------------------------
			// Logic
			//------------------------------------------------------------------------------
			SDL_Rect CheckRect;
			SDL_Rect TextRect;

			inline void DrawGraphical (void);

		//----------------------------------------------------------------------------------
		// Public members
		//----------------------------------------------------------------------------------
		public:
			CheckButton ();
			CheckButton (const char * name, SDL_Rect rect, ControlBackStyle backstyle,
						 Uint32 backcolor, const char * text, CRM32Pro_CFont * font,
						 ControlSkin * appearance = NULL, SDL_Surface * picture = NULL,
						 SDL_Surface * mousepointer = NULL, AlignmentStyle alignment = Left,
						 SDL_Surface * picturechecked = NULL, bool checked = false,
						 bool transparency = false, bool enable = true, bool visible = true);
			CheckButton (const CheckButton & obj);
			virtual CheckButton & operator = (const CheckButton & obj);
			~CheckButton ();


			//------------------------------------------------------------------------------
			// Logic
			//------------------------------------------------------------------------------
			virtual void Draw   (void);
			virtual bool Update (SDL_Event & event);

			virtual CheckButton & CopyFrom (const CheckButton & obj);

			void UpdateRects (void);


			//------------------------------------------------------------------------------
			// Gets
			//------------------------------------------------------------------------------
			
			/// Get the value of the control.
			inline bool GetValue (void) { return Value; }

			/// Get the picture when the value is true the control.
			inline SDL_Surface * GetPictureChecked (void) { return PictureChecked; }


			//------------------------------------------------------------------------------
			// Sets
			//------------------------------------------------------------------------------

			/// Set the coordinate X of the control.
			virtual inline void SetX (Sint16 val) { Rect.x = val; UpdateRects(); }

			/// Set the coordinate Y of the control.
			virtual inline void SetY (Sint16 val) { Rect.y = val; UpdateRects(); }

			/// Set the width of the control.
			virtual inline void SetWidth (Uint16 val) { Rect.w = val; UpdateRects(); }

			/// Set the height of the control.
			virtual inline void SetHeight (Uint16 val) { Rect.h = val; UpdateRects(); }

			/// Set the rect of the control.
			virtual inline void SetRect (SDL_Rect & val) { Rect = val; UpdateRects(); }
			
			/// Set the value of the control.
			inline void SetValue (bool val) { Value = val; }

			/// Set the picture when the value is true the control.
			inline void SetPictureChecked (SDL_Surface * val) { PictureChecked = val; }
	};
}
//******************************************************************************************
#endif
//******************************************************************************************
// CheckButton.h
//******************************************************************************************